@@ -1,8 +1,9 @@
 from sanic import Sanic
 from sanic_ext import Extend
 
-from sanic_api import api, logger, openapi
+from sanic_api import api, openapi
 
+from .api import ApiExtend
 from .logger import LoggerExtend
 
 
@@ -15,6 +16,6 @@ def init_api(app: Sanic):
     Returns:
 
     """
-    Extend.register(logger.LoggerExtend)
-    api.init(app)
+    Extend.register(LoggerExtend)
+    Extend.register(ApiExtend)
     openapi.init(app)
